@@ -1,28 +1,22 @@
 /* 
- * Copyright (C) 2001-2012 Michael Fuchs
+ * ### Copyright (C) 2008 Michael Fuchs ###
+ * ### All Rights Reserved.             ###
  *
- * This file is part of herold.
- * 
- * herold is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- * 
- * herold is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with herold.  If not, see <http://www.gnu.org/licenses/>.  
+ * Author: Michael Fuchs
+ * E-Mail: michael.fuchs@unico-group.com
+ * URL:    http://www.michael-a-fuchs.de
  */
 package org.dbdoclet.herold;
 
 import java.io.BufferedReader;
 import java.io.File;
+import java.io.FileInputStream;
 import java.io.FileNotFoundException;
+import java.io.FileOutputStream;
 import java.io.IOException;
+import java.io.InputStream;
 import java.io.InputStreamReader;
+import java.io.OutputStream;
 import java.io.StringWriter;
 import java.net.URL;
 import java.text.MessageFormat;
@@ -131,12 +125,28 @@ public class Herold {
 			}
 
 			File outFile = converter.processCommandLineOptions(options, script);
-			logger.info(String.format("Output file is %s.", outFile.getPath()));
-			script.setOutputFile(outFile);
-			script.setInputFile(optIn.getValue());
 
-			// System.out.println(script.dump());
-			converter.convert(script);
+			if (outFile != null) {
+				logger.info(String.format("Output file is %s.",
+						outFile.getPath()));
+			}
+
+			InputStream in = null;
+			OutputStream out = null;
+
+			if (optIn.isUnset()) {
+				in = System.in;
+			} else {
+				in = new FileInputStream(optIn.getValue());
+			}
+
+			if (optOut.isUnset()) {
+				out = System.out;
+			} else {
+				out = new FileOutputStream(optOut.getValue());
+			}
+
+			converter.convert(in, out, script);
 
 		} catch (OptionException oops) {
 
@@ -276,7 +286,8 @@ public class Herold {
 		selopt = new SelectOption(DbtConstants.SECTION_DOCBOOK.toLowerCase()
 				+ "-" + DbtConstants.PARAM_DOCBOOK_DOCUMENT_ELEMENT, "r");
 
-		String[] optv2 = { "article", "book", "reference", "section" };
+		String[] optv2 = { "article", "book", "reference", "part", "chapter",
+				"section" };
 		selopt.setList(optv2);
 		selopt.setDefault("article");
 		options.add(selopt);
@@ -295,7 +306,6 @@ public class Herold {
 
 		// in
 		optIn = new FileOption("in", "i");
-		optIn.isRequired(true);
 		optIn.isExisting(true);
 		options.add(optIn);
 
@@ -371,17 +381,17 @@ public class Herold {
 		println("herold version \"" + getVersion() + "\"");
 	}
 
-	public void convert(Script script) throws TrafoException {
+	public void convert(InputStream in, OutputStream out, Script script)
+			throws TrafoException {
 
-		DocBookTransformer trafo = new DocBookTransformer(
-				script.getOutputFile());
+		DocBookTransformer trafo = new DocBookTransformer();
 
 		if (verbose == true) {
 			trafo.addProgressListener(new ConsoleProgressListener(false));
 		}
 
 		trafo.setScript(script);
-		trafo.convert(script.getInputFile(), script.getOutputFile());
+		trafo.convert(in, out);
 
 		if (verbose == true) {
 			System.out.println();
@@ -415,11 +425,11 @@ public class Herold {
 				switch (option.getType()) {
 
 				case BOOLEAN:
-					script.setBoolParam(name, (Boolean) option.getValue());
+					script.setBoolParameter(name, (Boolean) option.getValue());
 					break;
 
 				default:
-					script.setTextParam(name, option.getValue().toString());
+					script.setTextParameter(name, option.getValue().toString());
 					break;
 				}
 			}
@@ -429,7 +439,7 @@ public class Herold {
 
 		File outFile;
 
-		if (optOut.isUnset()) {
+		if (optOut.isUnset() && optIn.isUnset() == false) {
 
 			String outFileName = FileServices.getFileBase(optIn.getValue())
 					+ ".xml";
@@ -447,12 +457,12 @@ public class Herold {
 		this.verbose = verbose;
 	}
 
-	public void convert(File htmlFile, File xmlFile) throws TrafoException {
+	public void convert(File htmlFile, File xmlFile) throws TrafoException,
+			FileNotFoundException {
 
 		Script script = new Script();
-		script.setInputFile(htmlFile);
-		script.setOutputFile(xmlFile);
-		convert(script);
+		convert(new FileInputStream(htmlFile), new FileOutputStream(xmlFile),
+				script);
 	}
 
 	public static void setSystemExitEnabled(boolean systemExitEnabled) {
