@@ -1,33 +1,36 @@
-/* 
- * Copyright (C) 2001-2012 Michael Fuchs
+/*
+ * $Id$
  *
- * This file is part of herold.
- * 
- * herold is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- * 
- * herold is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with herold.  If not, see <http://www.gnu.org/licenses/>.  
+ * ### Copybright (C) 2006 Michael Fuchs ###
+ * ### All Rights Reserved.             ###
+ *
+ * Author: Michael Fuchs
+ * E-Mail: michael.fuchs@unico-group.com
+ * URL:    http://www.michael-a-fuchs.de
  */
 package org.dbdoclet.trafo.html.docbook;
 
+import java.io.BufferedReader;
 import java.io.File;
 import java.io.FileOutputStream;
 import java.io.IOException;
+import java.io.InputStream;
+import java.io.InputStreamReader;
+import java.io.OutputStream;
+import java.io.OutputStreamWriter;
+import java.io.PrintWriter;
+import java.io.StringReader;
 import java.io.StringWriter;
 import java.util.ArrayList;
 import java.util.Iterator;
 
+import javax.xml.parsers.DocumentBuilder;
+import javax.xml.parsers.DocumentBuilderFactory;
+
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.dbdoclet.CanceledException;
+import org.dbdoclet.Sfv;
 import org.dbdoclet.progress.ProgressEvent;
 import org.dbdoclet.progress.ProgressListener;
 import org.dbdoclet.progress.ProgressManager;
@@ -43,6 +46,7 @@ import org.dbdoclet.trafo.html.docbook.editor.EditorInstruction;
 import org.dbdoclet.trafo.html.parser.HtmlParser;
 import org.dbdoclet.trafo.param.TextParam;
 import org.dbdoclet.trafo.script.Script;
+import org.dbdoclet.trafo.tag.docbook.Abstract;
 import org.dbdoclet.trafo.tag.docbook.DocBookDocument;
 import org.dbdoclet.trafo.tag.docbook.DocBookElement;
 import org.dbdoclet.trafo.tag.docbook.DocBookFragment;
@@ -65,7 +69,9 @@ import org.dbdoclet.xiphias.dom.TransformInstruction;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
+import org.w3c.dom.NodeList;
 import org.w3c.dom.Text;
+import org.xml.sax.InputSource;
 
 public class DocBookTransformer {
 
@@ -76,7 +82,6 @@ public class DocBookTransformer {
 	private static Log logger = LogFactory.getLog(DocBookTransformer.class);
 
 	private DocBookTagFactory dbfactory;
-	private File destinationFile;
 
 	/**
 	 * Einrückung für Debugging-Ausgaben
@@ -89,9 +94,8 @@ public class DocBookTransformer {
 	private Script script;
 	private final ProgressManager pm;
 
-	public DocBookTransformer(File destinationFile) {
+	public DocBookTransformer() {
 
-		this.destinationFile = destinationFile;
 		linkManager = new LinkManager();
 		pm = new ProgressManager(listeners);
 	}
@@ -134,7 +138,7 @@ public class DocBookTransformer {
 					DbtConstants.SECTION_HTML,
 					DbtConstants.PARAM_HTML_SOURCE_ENCODING,
 					DbtConstants.DEFAULT_SOURCE_ENCODING));
-			return convert(htmlCode, file);
+			return convert(htmlCode);
 		} catch (IOException oops) {
 			throw new TrafoException(oops);
 		}
@@ -146,7 +150,6 @@ public class DocBookTransformer {
 		try {
 
 			Script script = createDefaultScript();
-			setDestinationFile(destinationFile);
 			String buffer = convert(inFile);
 			FileServices.createParentDir(destinationFile);
 			FileServices.writeFromString(destinationFile, buffer, script
@@ -159,10 +162,7 @@ public class DocBookTransformer {
 		}
 	}
 
-	public String convert(String htmlCode, File destinationFile)
-			throws TrafoException {
-
-		this.destinationFile = destinationFile;
+	public String convert(String htmlCode) throws TrafoException {
 
 		String buffer;
 
@@ -194,19 +194,6 @@ public class DocBookTransformer {
 		return linkManager.createUniqueId(id);
 	}
 
-	public File getDestinationDirectory() {
-
-		if (destinationFile == null) {
-			return null;
-		}
-
-		return destinationFile.getParentFile();
-	}
-
-	public File getDestinationFile() {
-		return destinationFile;
-	}
-
 	public ArrayList<ElementImpl> getLinkList() {
 
 		return linkManager.getLinkList();
@@ -238,10 +225,6 @@ public class DocBookTransformer {
 		return linkManager.getUsedIdList();
 	}
 
-	public void setDestinationFile(File destinationFile) {
-		this.destinationFile = destinationFile;
-	}
-
 	public void setScript(Script script) {
 
 		this.script = script;
@@ -511,12 +494,6 @@ public class DocBookTransformer {
 				lang = language;
 			}
 
-			// pm.nextStage();
-			// if (scriptManager.htmlScriptsAvailable()) {
-			// pm.setProgressMaximum(elemCount);
-			// customizeHtml(documentElement);
-			// }
-			//
 			DocBookDocument doc = new DocBookDocument();
 			doc.setXmlEncoding(script.getTextParameter(
 					DbtConstants.SECTION_DOCBOOK,
@@ -558,40 +535,19 @@ public class DocBookTransformer {
 					DbtConstants.PARAM_DOCBOOK_TITLE, null);
 
 			if (title != null && title.trim().length() > 0) {
-
 				info.appendChild(dbf.createTitle(title));
-
 			} else {
+				generateTitle(htmlDoc, dbf, info);
+			}
 
-				HtmlElement elem = (HtmlElement) XPathServices.getNode(htmlDoc,
-						"/html/head/title");
+			String abstractText = script.getTextParameter(
+					DbtConstants.SECTION_DOCBOOK,
+					DbtConstants.PARAM_DOCBOOK_ABSTRACT, null);
 
-				if (elem == null) {
-
-					for (int i = 1; i <= 6; i++) {
-
-						if (elem == null) {
-							elem = (HtmlElement) XPathServices.getNode(htmlDoc,
-									"/html/body/h" + i + "[1]");
-						}
-					}
-				}
-
-				if (elem != null) {
-
-					info.appendChild(dbf.createTitle(elem.getTextContent()));
-
-				} else {
-
-					Text text = (Text) XPathServices.getNode(htmlDoc,
-							"//text()[1]");
-
-					if (text != null) {
-						info.appendChild(dbf.createTitle(text.getData()));
-					} else {
-						info.appendChild(dbf.createTitle("Herold"));
-					}
-				}
+			if (abstractText != null) {
+				Abstract abstractElement = dbf.createAbstract();
+				info.appendChild(abstractElement);
+				createAbstract(doc, abstractElement, abstractText);
 			}
 
 			doc.setDocumentElement(rootElement);
@@ -612,6 +568,77 @@ public class DocBookTransformer {
 
 	}
 
+	private void createAbstract(Document doc, Abstract abstractElement,
+			String abstractText) {
+
+		if (abstractText.trim().startsWith("<")) {
+			abstractText = "<abstract>" + abstractText + "</abstract>";
+		} else {
+			abstractText = "<abstract><para>" + abstractText
+					+ "</para></abstract>";
+		}
+
+		try {
+			DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory
+					.newInstance();
+			DocumentBuilder documentBuilder = documentBuilderFactory
+					.newDocumentBuilder();
+			Document docAbstract = documentBuilder.parse(new InputSource(
+					new StringReader(abstractText)));
+
+			Element documentElement = docAbstract.getDocumentElement();
+
+			documentElement = (Element) doc.importNode(documentElement, true);
+
+			if (documentElement != null && documentElement.hasChildNodes()) {
+
+				NodeList childList = documentElement.getChildNodes();
+
+				for (int i = 0; i < childList.getLength(); i++) {
+
+					Node child = childList.item(i);
+					abstractElement.appendChild(child);
+				}
+			}
+
+		} catch (Exception oops) {
+
+			logger.error("Parsing abstract failed!", oops);
+		}
+	}
+
+	private void generateTitle(HtmlDocument htmlDoc, DocBookTagFactory dbf,
+			Info info) {
+		HtmlElement elem = (HtmlElement) XPathServices.getNode(htmlDoc,
+				"/html/head/title");
+
+		if (elem == null) {
+
+			for (int i = 1; i <= 6; i++) {
+
+				if (elem == null) {
+					elem = (HtmlElement) XPathServices.getNode(htmlDoc,
+							"/html/body/h" + i + "[1]");
+				}
+			}
+		}
+
+		if (elem != null) {
+
+			info.appendChild(dbf.createTitle(elem.getTextContent()));
+
+		} else {
+
+			Text text = (Text) XPathServices.getNode(htmlDoc, "//text()[1]");
+
+			if (text != null) {
+				info.appendChild(dbf.createTitle(text.getData()));
+			} else {
+				info.appendChild(dbf.createTitle("Herold"));
+			}
+		}
+	}
+
 	public String transformFragment(String htmlCode) throws TrafoException {
 		return transformFragment(htmlCode, new TrafoResult());
 	}
@@ -1067,4 +1094,51 @@ public class DocBookTransformer {
 		serializer.write(elem, buffer);
 		return buffer;
 	}
+
+	public void convert(InputStream in, OutputStream out) throws TrafoException {
+
+		try {
+
+			String encoding = script.getTextParameter(
+					DbtConstants.SECTION_HTML,
+					DbtConstants.PARAM_HTML_SOURCE_ENCODING, "UTF-8");
+
+			BufferedReader reader = new BufferedReader(new InputStreamReader(
+					in, encoding));
+
+			StringWriter buffer = new StringWriter();
+			String line = reader.readLine();
+
+			while (line != null) {
+				buffer.append(line);
+				buffer.append(Sfv.LSEP);
+				line = reader.readLine();
+			}
+
+			reader.close();
+
+			String docBookCode = convert(buffer.toString());
+
+			encoding = script.getTextParameter(DbtConstants.SECTION_DOCBOOK,
+					DbtConstants.PARAM_DOCBOOK_ENCODING, "UTF-8");
+
+			PrintWriter writer = new PrintWriter(new OutputStreamWriter(out,
+					encoding));
+
+			BufferedReader docBookReader = new BufferedReader(new StringReader(
+					docBookCode));
+			line = docBookReader.readLine();
+			while (line != null) {
+				writer.println(line);
+				line = docBookReader.readLine();
+			}
+
+			docBookReader.close();
+			writer.close();
+
+		} catch (IOException oops) {
+
+			throw new TrafoException(oops);
+		}
+	}
 }
