@@ -1,20 +1,10 @@
 /* 
- * Copyright (C) 2001-2012 Michael Fuchs
+ * ### Copyright (C) 2008 Michael Fuchs ###
+ * ### All Rights Reserved.             ###
  *
- * This file is part of herold.
- * 
- * herold is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- * 
- * herold is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with herold.  If not, see <http://www.gnu.org/licenses/>.  
+ * Author: Michael Fuchs
+ * E-Mail: michael.fuchs@dbdoclet.org
+ * URL:    http://www.michael-a-fuchs.de
  */
 package org.dbdoclet.trafo.html.docbook.editor;
 
@@ -99,12 +89,18 @@ public class Editor {
 		if (script.isParameterOn(DbtConstants.SECTION_DOCBOOK,
 				DbtConstants.PARAM_DOCBOOK_CREATE_REMAP_ATTRIBUTE, false)) {
 
-			String remap = String.format("%s:%d:%d", html.getTagName(),
-					html.getLine(), html.getColumn());
-			dbk.setRemap(remap);
+			createRemapAttribute(html, dbk);
 			dbk.setLine(html.getLine());
 			dbk.setColumn(html.getColumn());
 		}
+
+		dbk.setUserData("html", html, null);
+	}
+
+	private void createRemapAttribute(HtmlElement html, DocBookElement dbk) {
+		String remap = String.format("%s:%d:%d", html.getTagName(),
+				html.getLine(), html.getColumn());
+		dbk.setRemap(remap);
 	}
 
 	public EditorInstruction edit(EditorInstruction vo) throws EditorException {
