@@ -1,20 +1,10 @@
 /* 
- * Copyright (C) 2001-2012 Michael Fuchs
+ * ### Copyright (C) 2008 Michael Fuchs ###
+ * ### All Rights Reserved.             ###
  *
- * This file is part of herold.
- * 
- * herold is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- * 
- * herold is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with herold.  If not, see <http://www.gnu.org/licenses/>.  
+ * Author: Michael Fuchs
+ * E-Mail: michael.fuchs@dbdoclet.org
+ * URL:    http://www.michael-a-fuchs.de
  */
 package org.dbdoclet.trafo.html.docbook.editor;
 
@@ -438,10 +428,9 @@ public class HeaderBaseEditor extends Editor {
 			if (parent != null) {
 
 				String tag = header.getNodeName();
-				String remap = parent.getRemap();
-
 				int tagLevel = getLevelByTagName(tag);
-				int parentLevel = getLevelByTagName(remap);
+
+				int parentLevel = getLevelByTagName(parent);
 
 				while (tagLevel != -1 && parentLevel != -1
 						&& parentLevel >= tagLevel) {
@@ -454,7 +443,7 @@ public class HeaderBaseEditor extends Editor {
 					}
 
 					parent = ancestor;
-					parentLevel = getLevelByTagName(parent.getRemap());
+					parentLevel = getLevelByTagName(parent);
 				}
 
 				break;
@@ -464,16 +453,24 @@ public class HeaderBaseEditor extends Editor {
 		return parent;
 	}
 
-	private int getLevelByTagName(String tagName) {
+	private int getLevelByTagName(DocBookElement parent) {
 
-		if (tagName == null) {
+		String tagName = null;
+
+		Element htmlOrigin = (Element) parent.getUserData("html");
+
+		if (htmlOrigin == null) {
 			return -1;
 		}
 
-		int index = tagName.indexOf(':');
+		tagName = htmlOrigin.getTagName();
 
-		if (index != -1) {
-			tagName = tagName.substring(0, index);
+		return getLevelByTagName(tagName);
+	}
+
+	private int getLevelByTagName(String tagName) {
+		if (tagName == null) {
+			return -1;
 		}
 
 		if (tagName.length() != 2) {
