@@ -1,12 +1,8 @@
 package org.dbdoclet.trafo.script;
 
-import java.io.File;
 import java.util.ArrayList;
 import java.util.LinkedHashMap;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
 
-import org.dbdoclet.service.FileServices;
 import org.dbdoclet.trafo.param.BooleanParam;
 import org.dbdoclet.trafo.param.NumberParam;
 import org.dbdoclet.trafo.param.Param;
@@ -20,8 +16,6 @@ public class Script {
 	public static final String SYSPARAM_TRANSFORMATION_NAME = "transformation.name";
 	private static final String SECTION_INPUT = "input";
 	private static final String SECTION_OUTPUT = "output";
-	private static final String PARAM_DIR = "dir";
-	private static final String PARAM_FILE = "file";
 	private static final String PARAM_FORMAT = "format";
 
 	private final LinkedHashMap<String, LinkedHashMap<String, LinkedHashMap<String, Param<?>>>> namespaceMap;
@@ -178,90 +172,6 @@ public class Script {
 		}
 	}
 
-	public ArrayList<File[]> getInOutFilePair() {
-
-		ArrayList<File[]> pairList = new ArrayList<File[]>();
-
-		File inf = getInputFile();
-		File outf = getOutputFile();
-		File ind = getInputDirectory();
-		File outd = getOutputDirectory();
-
-		if (ind != null) {
-			inf = new File(FileServices.appendFileName(ind,
-					inf.getAbsolutePath()));
-		}
-
-		if (outd != null) {
-			outf = new File(FileServices.appendFileName(outd,
-					outf.getAbsolutePath()));
-		}
-
-		if (inf.exists() && outf.exists()) {
-
-			File[] filePair = new File[2];
-			filePair[0] = inf;
-			filePair[1] = outf;
-			pairList.add(filePair);
-			return pairList;
-		}
-
-		if (ind != null && inf != null && outd != null && outf != null) {
-
-			Pattern pattern = Pattern.compile(inf.getName());
-
-			for (File file : inf.listFiles()) {
-
-				Matcher matcher = pattern.matcher(file.getName());
-
-				if (matcher.matches()) {
-
-					String outFileName = FileServices.appendFileName(outd,
-							matcher.replaceFirst(outf.getName()));
-
-					File[] filePair = new File[2];
-					filePair[0] = file;
-					filePair[1] = new File(outFileName);
-					pairList.add(filePair);
-				}
-			}
-		}
-
-		return pairList;
-	}
-
-	public File getInputDirectory() {
-		return getInputDirectory(DEFAULT_NAMESPACE);
-	}
-
-	public File getInputDirectory(String namespace) {
-
-		String fileName = getTextParameter(namespace, SECTION_INPUT, PARAM_DIR,
-				null);
-
-		if (fileName == null) {
-			return null;
-		}
-
-		return new File(fileName);
-	}
-
-	public File getInputFile() {
-		return getInputFile(DEFAULT_NAMESPACE);
-	}
-
-	public File getInputFile(String namespace) {
-
-		String fileName = getTextParameter(namespace, SECTION_INPUT,
-				PARAM_FILE, null);
-
-		if (fileName == null) {
-			return null;
-		}
-
-		return new File(fileName);
-	}
-
 	public String getInputFormat() {
 		return getInputFormat(DEFAULT_NAMESPACE);
 	}
@@ -286,38 +196,6 @@ public class Script {
 		return (Integer) param.getValue();
 	}
 
-	public File getOutputDirectory() {
-		return getOutputDirectory(DEFAULT_NAMESPACE);
-	}
-
-	public File getOutputDirectory(String namespace) {
-
-		String fileName = getTextParameter(namespace, SECTION_OUTPUT,
-				PARAM_DIR, null);
-
-		if (fileName == null) {
-			return null;
-		}
-
-		return new File(fileName);
-	}
-
-	public File getOutputFile() {
-		return getOutputFile(DEFAULT_NAMESPACE);
-	}
-
-	public File getOutputFile(String namespace) {
-
-		String fileName = getTextParameter(namespace, SECTION_OUTPUT,
-				PARAM_FILE, null);
-
-		if (fileName == null) {
-			return null;
-		}
-
-		return new File(fileName);
-	}
-
 	public String getOutputFormat() {
 		return getOutputFormat(DEFAULT_NAMESPACE);
 	}
@@ -544,7 +422,7 @@ public class Script {
 		currentParamMap = paramMap;
 	}
 
-	public void setBoolParam(String name, boolean flag) {
+	public void setBoolParameter(String name, boolean flag) {
 
 		if (currentParamMap == null) {
 			throw new IllegalStateException(
@@ -564,20 +442,6 @@ public class Script {
 		}
 	}
 
-	public void setInputDirectory(File file) {
-		selectSection(DEFAULT_NAMESPACE, SECTION_INPUT);
-		setTextParam(PARAM_DIR, file.getPath());
-	}
-
-	public void setInputFile(File file) {
-		setInputFile(DEFAULT_NAMESPACE, file);
-	}
-
-	public void setInputFile(String namespace, File file) {
-		selectSection(namespace, SECTION_INPUT);
-		setTextParam(PARAM_FILE, file.getPath());
-	}
-
 	public void setListParam(String name, ArrayList<String> textList) {
 
 		@SuppressWarnings("unchecked")
@@ -587,22 +451,6 @@ public class Script {
 		currentParamMap.put(name, param);
 	}
 
-	public void setOutputDirectory(File file) {
-		selectSection(DEFAULT_NAMESPACE, SECTION_OUTPUT);
-		setTextParam(PARAM_DIR, file.getPath());
-	}
-
-	public void setOutputFile(File file) {
-		setOutputFile(DEFAULT_NAMESPACE, file);
-	}
-
-	public void setOutputFile(String namespace, File file) {
-		selectSection(namespace, SECTION_OUTPUT);
-		setTextParam(PARAM_FILE, file.getPath());
-		fireScriptEvent(new ScriptEvent<File>(this, file,
-				ScriptEvent.Type.OUTPUT_FILE_CHANGED));
-	}
-
 	public void setSystemParameter(String name, String value) {
 		setSystemParameter(DEFAULT_NAMESPACE, name, value);
 	}
@@ -614,7 +462,7 @@ public class Script {
 		paramMap.put(name, new TextParam(name, value));
 	}
 
-	public void setTextParam(String name, String text) {
+	public void setTextParameter(String name, String text) {
 
 		if (currentParamMap == null) {
 			throw new IllegalStateException(
