@@ -1,20 +1,10 @@
 /* 
- * Copyright (C) 2001-2012 Michael Fuchs
+ * ### Copyright (C) 2001-2007 Michael Fuchs ###
+ * ### All Rights Reserved.             ###
  *
- * This file is part of herold.
- * 
- * herold is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- * 
- * herold is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with herold.  If not, see <http://www.gnu.org/licenses/>.  
+ * Author: Michael Fuchs
+ * E-Mail: michael.fuchs@unico-group.com
+ * URL:    http://www.michael-a-fuchs.de
  */
 package org.dbdoclet.xiphias.dom;
 
@@ -231,7 +221,8 @@ public class NodeImpl implements Node {
 			return appendChild((NodeImpl) newChild);
 		}
 
-		return null;
+		throw new IllegalArgumentException("The new child must be of type "
+				+ NodeImpl.class.getName());
 	}
 
 	/**
@@ -1141,7 +1132,7 @@ public class NodeImpl implements Node {
 			userDataMap.put(key, data);
 		}
 
-		return null;
+		return data;
 	}
 
 	public void swapWithParent() {
